@@ -16,7 +16,7 @@
 #define KMER_MAPPER_LOGGER_H_
 
 #include "sequence/sequence.hpp"
-#include "common/assembly_graph/core/action_handlers.hpp"
+#include "assembly_graph/core/action_handlers.hpp"
 #include "utils/standard_base.hpp"
 
 namespace debruijn {
