@@ -468,6 +468,7 @@ class ExcludingExtensionChooser: public ExtensionChooser {
         VERIFY(!weights.empty());
         auto max_weight = (--weights.end())->first;
         EdgeContainer top = FindPossibleEdges(weights, max_weight);
+        DEBUG("Top-scored edges " << top.size());
         EdgeContainer result;
         if (CheckThreshold(max_weight)) {
             result = top;
@@ -500,6 +501,7 @@ public:
         path.PrintDEBUG();
         EdgeContainer result = edges;
         ExcludeEdges(path, result, to_exclude);
+        DEBUG("Excluded " << to_exclude.size() << " edges")
         result = FindFilteredEdges(path, result, to_exclude);
         if (result.size() == 1) {
             DEBUG("Paired-end extension chooser helped");
@@ -533,6 +535,7 @@ protected:
                 if (!HasIdealInfo(path_edge,
                            edges.at(i).e_,
                            path.LengthAt(index))) {
+                    DEBUG("Excluding edge because of no ideal info #" << index)
                     to_exclude.insert((size_t) index);
                 }
             }
@@ -550,6 +553,7 @@ protected:
 
         for (auto e_w_ec : edge_2_extension_cnt) {
             if (e_w_ec.second == edges.size()) {
+                DEBUG("Excluding edge because of ambiguous paired info #" << e_w_ec.first)
                 to_exclude.insert(e_w_ec.first);
             }
         }
@@ -704,6 +708,7 @@ class ScaffoldingExtensionChooser : public ExtensionChooser {
 
     void FindBestFittedEdgesForClustered(const BidirectionalPath& path, const set<EdgeId>& edges, EdgeContainer& result) const {
         for (EdgeId e : edges) {
+            DEBUG("Analyzing edge " << g_.int_id(e))
             std::vector<pair<int, double>> histogram;
             CountAvrgDists(path, e, histogram);
             double sum = 0.0;
@@ -716,6 +721,7 @@ class ScaffoldingExtensionChooser : public ExtensionChooser {
             }
 
             int gap = CountMean(histogram);
+            DEBUG("Gap = " << gap)
             if (HasIdealInfo(path, e, gap)) {
                 DEBUG("scaffolding " << g_.int_id(e) << " gap " << gap);
                 result.push_back(EdgeWithDistance(e, gap));
@@ -760,12 +766,21 @@ public:
     }
 
     EdgeContainer Filter(const BidirectionalPath& path, const EdgeContainer& edges) const override {
+        DEBUG("Extension chooser filter, threshold = " << cl_weight_threshold_)
         if (edges.empty()) {
             return edges;
         }
         set<EdgeId> candidates = FindCandidates(path);
+        for (auto e : path) {
+            if (candidates.find(e) != candidates.end()) {
+                DEBUG(g_.int_id(e) << " is removed due to presence in the path")
+                candidates.erase(e);
+            }
+        }
+        DEBUG("Found candidates:" << candidates.size())
         EdgeContainer result;
         FindBestFittedEdgesForClustered(path, candidates, result);
+        DEBUG("Detected possible edges to scaffold: " << result.size())
         return result;
     }
 
