@@ -28,7 +28,8 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeLongReadsExtender(size_t lib_
     //TODO params
     size_t resolvable_repeat_length_bound = 10000ul;
     if (!dataset_info_.reads[lib_index].is_contig_lib()) {
-        resolvable_repeat_length_bound = std::max(resolvable_repeat_length_bound, lib.data().read_length);
+        //TODO does max make sense here?
+        resolvable_repeat_length_bound = std::max(resolvable_repeat_length_bound, lib.data().unmerged_read_length);
     }
     INFO("resolvable_repeat_length_bound set to " << resolvable_repeat_length_bound);
     bool investigate_short_loop = lib.is_contig_lib() || lib.is_long_read_lib() || support_.UseCoverageResolverForSingleReads(lib.type());
@@ -51,7 +52,7 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeLongEdgePEExtender(size_t lib
     shared_ptr<WeightCounter> wc =
         make_shared<PathCoverWeightCounter>(gp_.g, paired_lib,
                                             params_.pset.normalize_weight,
-                                            support_.SingleThresholdForLib(params_.pset, lib.data().pi_threshold));
+                                            params_.pset.extension_options.single_threshold);
     auto opts = support_.GetExtensionOpts(paired_lib, params_.pset);
     shared_ptr<ExtensionChooser> extension =
         make_shared<LongEdgeExtensionChooser>(gp_.g, wc,
@@ -81,7 +82,7 @@ shared_ptr<GapAnalyzer> ExtendersGenerator::MakeGapAnalyzer(double is_variation)
                                                          pset.scaffolder_options.min_gap_score,
                                                          pset.scaffolder_options.short_overlap,
                                                          (int) pset.scaffolder_options.basic_overlap_coeff
-                                                             * dataset_info_.RL()));
+                                                             * dataset_info_.RL));
 
     //todo introduce explicit must_overlap_coeff and rename max_can_overlap -> can_overlap_coeff
     return std::make_shared<CompositeGapAnalyzer>(gp_.g,
@@ -189,11 +190,11 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeCoordCoverageExtender(size_t
     const auto& lib = dataset_info_.reads[lib_index];
     shared_ptr<PairedInfoLibrary> paired_lib = MakeNewLib(gp_.g, lib, gp_.clustered_indices[lib_index]);
 
-    auto provider = make_shared<CoverageAwareIdealInfoProvider>(gp_.g, paired_lib, dataset_info_.RL());
+    auto provider = make_shared<CoverageAwareIdealInfoProvider>(gp_.g, paired_lib, lib.data().unmerged_read_length);
 
     auto meta_wc = make_shared<PathCoverWeightCounter>(gp_.g, paired_lib,
                                                        params_.pset.normalize_weight,
-                                                       support_.SingleThresholdForLib(params_.pset, lib.data().pi_threshold),
+                                                       params_.pset.extension_options.single_threshold,
                                                        provider);
 
     auto permissive_pi_chooser = make_shared<IdealBasedExtensionChooser>(gp_.g,
@@ -221,10 +222,10 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakeRNAExtender(size_t lib_index,
     shared_ptr<PairedInfoLibrary> paired_lib = MakeNewLib(gp_.g, lib, gp_.clustered_indices[lib_index]);
 //    INFO("Threshold for lib #" << lib_index << ": " << paired_lib->GetSingleThreshold());
 
-    auto cip = make_shared<CoverageAwareIdealInfoProvider>(gp_.g, paired_lib, dataset_info_.RL());
+    auto cip = make_shared<CoverageAwareIdealInfoProvider>(gp_.g, paired_lib, lib.data().unmerged_read_length);
     shared_ptr<WeightCounter> wc =
         make_shared<PathCoverWeightCounter>(gp_.g, paired_lib, params_.pset.normalize_weight,
-                                            support_.SingleThresholdForLib(params_.pset, lib.data().pi_threshold),
+                                            params_.pset.extension_options.single_threshold,
                                             cip);
 
     auto opts = support_.GetExtensionOpts(paired_lib, params_.pset);
@@ -267,17 +268,16 @@ shared_ptr<SimpleExtender> ExtendersGenerator::MakePEExtender(size_t lib_index,
 //    INFO("Threshold for lib #" << lib_index << ": " << paired_lib->GetSingleThreshold());
 
     shared_ptr<CoverageAwareIdealInfoProvider> iip = nullptr;
-    if (opts.use_default_single_threshold) {
-        if (params_.uneven_depth) {
-            iip = make_shared<CoverageAwareIdealInfoProvider>(gp_.g, paired_lib, dataset_info_.RL());
-        } else {
-            double lib_cov = support_.EstimateLibCoverage(lib_index);
-            INFO("Estimated coverage of library #" << lib_index << " is " << lib_cov);
-            iip = make_shared<GlobalCoverageAwareIdealInfoProvider>(gp_.g, paired_lib, dataset_info_.RL(), lib_cov);
-        }
+    if (params_.uneven_depth || params_.mode == config::pipeline_type::moleculo) {
+        iip = make_shared<CoverageAwareIdealInfoProvider>(gp_.g, paired_lib, lib.data().unmerged_read_length);
+    } else {
+        double lib_cov = support_.EstimateLibCoverage(lib_index);
+        INFO("Estimated coverage of library #" << lib_index << " is " << lib_cov);
+        iip = make_shared<GlobalCoverageAwareIdealInfoProvider>(gp_.g, paired_lib, lib.data().unmerged_read_length, lib_cov);
     }
+
     auto wc = make_shared<PathCoverWeightCounter>(gp_.g, paired_lib, params_.pset.normalize_weight,
-                                                  support_.SingleThresholdForLib(params_.pset, lib.data().pi_threshold),
+                                                  params_.pset.extension_options.single_threshold,
                                                   iip);
 
     auto extension_chooser = make_shared<SimpleExtensionChooser>(gp_.g, wc,
