@@ -271,9 +271,8 @@ void PathExtendLauncher::CleanPaths(PathContainer &paths, const pe_config::Param
     paths.SortByLength();
 }
 
-
 size_t PathExtendLauncher::GetLengthCutoff(size_t abs_cutoff, double rel_cutoff) const {
-    int rel_len = int(rel_cutoff * double(cfg::get().ds.RL())) - int(cfg::get().K);
+    int rel_len = int(rel_cutoff * double(cfg::get().ds.RL)) - int(cfg::get().K);
     int abs_len = int(abs_cutoff) - int(cfg::get().K);
     size_t result = (size_t) max(0, max(rel_len, abs_len));
 
@@ -327,14 +326,14 @@ void PathExtendLauncher::FillPathContainer(size_t lib_index, size_t size_thresho
     std::vector<PathInfo<Graph>> paths;
     gp_.single_long_reads[lib_index].SaveAllPaths(paths);
     for (const auto &path: paths) {
-        const auto &edges = path.getPath();
+        const auto &edges = path.path();
         if (edges.size() <= size_threshold)
             continue;
 
         BidirectionalPath *new_path = new BidirectionalPath(gp_.g, edges);
         BidirectionalPath *conj_path = new BidirectionalPath(new_path->Conjugate());
-        new_path->SetWeight((float) path.getWeight());
-        conj_path->SetWeight((float) path.getWeight());
+        new_path->SetWeight((float) path.weight());
+        conj_path->SetWeight((float) path.weight());
         unique_data_.long_reads_paths_[lib_index].AddPair(new_path, conj_path);
     }
     DEBUG("Long reads paths " << unique_data_.long_reads_paths_[lib_index].size());
@@ -498,24 +497,23 @@ void PathExtendLauncher::Launch() {
     Extenders extenders = ConstructExtenders(cover_map, used_unique_storage);
     CompositeExtender composite_extender(gp_.g, cover_map,
                                          used_unique_storage,
-                                         extenders,
-                                         params_.max_path_diff);
+                                         extenders);
 
     auto paths = resolver.ExtendSeeds(seeds, composite_extender);
     DebugOutputPaths(paths, "raw_paths");
 
     RemoveOverlapsAndArtifacts(paths, cover_map, resolver);
-    DebugOutputPaths(paths, "before_loop_traversal");
-    //TODO think about ordering of path polisher vs loop traversal
-    TraverseLoops(paths, cover_map);
-    DebugOutputPaths(paths, "loop_traveresed");
+    DebugOutputPaths(paths, "before_path_polishing");
 
     //TODO does path polishing correctly work with coverage map
     PolishPaths(paths, gp_.contig_paths, cover_map);
-    DebugOutputPaths(gp_.contig_paths, "polished_paths");
-
     //TODO use move assignment to original map here
     GraphCoverageMap polished_map(gp_.g, gp_.contig_paths, true);
+    DebugOutputPaths(gp_.contig_paths, "polished_paths");
+
+    TraverseLoops(gp_.contig_paths, polished_map);
+    DebugOutputPaths(gp_.contig_paths, "loop_traveresed");
+
     RemoveOverlapsAndArtifacts(gp_.contig_paths, polished_map, resolver);
     DebugOutputPaths(gp_.contig_paths, "overlap_removed");
 
