@@ -9,7 +9,7 @@
 #include "io/reads/rc_reader_wrapper.hpp"
 #include "io/reads/sequence_reader.hpp"
 #include "diff_masking.hpp"
-#include "common/adt/bag.hpp"
+#include "adt/bag.hpp"
 #include "io/reads/vector_reader.hpp"
 #include "visualization/graph_colorer.hpp"
 
@@ -911,7 +911,7 @@ const vector<io::SingleRead> MakeReads(const vector<string>& reads, const vector
 vector<string> mosaic_names(size_t n) {
     vector<string> ans;
     for (size_t i = 0; i < n; ++i) {
-        ans.push_back("mosaic_" + ToString(i));
+        ans.push_back("mosaic_" + std::to_string(i));
     }
     return ans;
 }
@@ -968,8 +968,8 @@ void DrawGraph(const vector<StrandRange>& all_ranges,
             50
             /*numeric_limits<size_t>::max()*/);
 
-    path::remove_if_exists("mosaic_pics");
-    path::make_dir("mosaic_pics");
+    fs::remove_if_exists("mosaic_pics");
+    fs::make_dir("mosaic_pics");
     INFO("Writing components");
     visualization::visualization_utils::WriteComponents(gp.g, "mosaic_pics/", splitter,
             visualization::graph_colorer::DefaultColorer(gp.g), labeler);
