@@ -24,15 +24,15 @@ using namespace std;
 
 namespace hammer {
 
-void InitializeSubKMerPositions() {
+void InitializeSubKMerPositions(int tau) {
   std::ostringstream log_sstream;
   log_sstream.str("");
-  Globals::subKMerPositions = new std::vector<uint32_t>(cfg::get().general_tau + 2);
-  for (uint32_t i=0; i < (uint32_t)(cfg::get().general_tau + 1); ++i) {
-    Globals::subKMerPositions->at(i) = (i * K / (cfg::get().general_tau + 1) );
+  Globals::subKMerPositions = new std::vector<uint32_t>(tau + 2);
+  for (uint32_t i=0; i < (uint32_t)(tau + 1); ++i) {
+    Globals::subKMerPositions->at(i) = (i * K / (tau + 1) );
     log_sstream << Globals::subKMerPositions->at(i) << " ";
   }
-  Globals::subKMerPositions->at(cfg::get().general_tau + 1) = K;
+  Globals::subKMerPositions->at(tau + 1) = K;
   INFO("Hamming graph threshold tau=" << cfg::get().general_tau << ", k=" << K << ", subkmer positions = [ " << log_sstream.str() << "]" );
 }
 
@@ -74,9 +74,8 @@ string getFilename( const string & dirprefix, int iter_count, const string & suf
   return tmp.str();
 }
 
-void CorrectReadsBatch(std::vector<bool> &res,
+CorrectionStats CorrectReadsBatch(std::vector<bool> &res,
                        std::vector<Read> &reads, size_t buf_size,
-                       size_t &changedReads, size_t &changedNucleotides, size_t &uncorrectedNucleotides, size_t &totalNucleotides,
                        const KMerData &data) {
   unsigned correct_nthreads = min(cfg::get().correct_nthreads, cfg::get().general_max_nthreads);
   bool discard_singletons = cfg::get().bayes_discard_only_singletons;
@@ -94,14 +93,16 @@ void CorrectReadsBatch(std::vector<bool> &res,
       res[i] = false;
   }
 
-  changedReads += corrector.changed_reads();
-  changedNucleotides += corrector.changed_nucleotides();
-  uncorrectedNucleotides += corrector.uncorrected_nucleotides();
-  totalNucleotides += corrector.total_nucleotides();
+  CorrectionStats stats;
+
+  stats.changedReads += corrector.changed_reads();
+  stats.changedNucleotides += corrector.changed_nucleotides();
+  stats.uncorrectedNucleotides += corrector.uncorrected_nucleotides();
+  stats.totalNucleotides += corrector.total_nucleotides();
+  return stats;
 }
 
-void CorrectReadFile(const KMerData &data,
-                     size_t &changedReads, size_t &changedNucleotides, size_t &uncorrectedNucleotides, size_t &totalNucleotides,
+CorrectionStats CorrectReadFile(const KMerData &data,
                      const std::string &fname,
                      std::ofstream *outf_good, std::ofstream *outf_bad) {
   int qvoffset = cfg::get().input_qvoffset;
@@ -116,6 +117,7 @@ void CorrectReadFile(const KMerData &data,
   VERIFY(irs.is_open());
 
   unsigned buffer_no = 0;
+  CorrectionStats stats;
   while (!irs.eof()) {
     size_t buf_size = 0;
     for (; buf_size < read_buffer_size && !irs.eof(); ++buf_size) {
@@ -124,9 +126,8 @@ void CorrectReadFile(const KMerData &data,
     }
     INFO("Prepared batch " << buffer_no << " of " << buf_size << " reads.");
 
-    CorrectReadsBatch(res, reads, buf_size,
-                      changedReads, changedNucleotides, uncorrectedNucleotides, totalNucleotides,
-                      data);
+    stats += CorrectReadsBatch(res, reads, buf_size,
+                               data);
 
     INFO("Processed batch " << buffer_no);
     for (size_t i = 0; i < buf_size; ++i) {
@@ -135,10 +136,10 @@ void CorrectReadFile(const KMerData &data,
     INFO("Written batch " << buffer_no);
     ++buffer_no;
   }
+  return stats;
 }
 
-void CorrectPairedReadFiles(const KMerData &data,
-                            size_t &changedReads, size_t &changedNucleotides, size_t &uncorrectedNucleotides, size_t &totalNucleotides,
+CorrectionStats CorrectPairedReadFiles(const KMerData &data,
                             const std::string &fnamel, const std::string &fnamer,
                             ofstream * ofbadl, ofstream * ofcorl, ofstream * ofbadr, ofstream * ofcorr, ofstream * ofunp) {
   int qvoffset = cfg::get().input_qvoffset;
@@ -155,6 +156,7 @@ void CorrectPairedReadFiles(const KMerData &data,
 
   ireadstream irsl(fnamel, qvoffset), irsr(fnamer, qvoffset);
   VERIFY(irsl.is_open()); VERIFY(irsr.is_open());
+  CorrectionStats stats;
 
   while (!irsl.eof() && !irsr.eof()) {
     size_t buf_size = 0;
@@ -165,11 +167,9 @@ void CorrectPairedReadFiles(const KMerData &data,
     }
     INFO("Prepared batch " << buffer_no << " of " << buf_size << " reads.");
 
-    CorrectReadsBatch(left_res, l, buf_size,
-                      changedReads, changedNucleotides, uncorrectedNucleotides, totalNucleotides,
+    stats += CorrectReadsBatch(left_res, l, buf_size,
                       data);
-    CorrectReadsBatch(right_res, r, buf_size,
-                      changedReads, changedNucleotides, uncorrectedNucleotides, totalNucleotides,
+    stats += CorrectReadsBatch(right_res, r, buf_size,
                       data);
 
     INFO("Processed batch " << buffer_no);
@@ -185,7 +185,9 @@ void CorrectPairedReadFiles(const KMerData &data,
     INFO("Written batch " << buffer_no);
     ++buffer_no;
   }
-  VERIFY_MSG(irsl.eof() && irsr.eof(), "Pair of read files " + fnamel + " and " + fnamer + " contain unequal amount of reads");
+  if (!irsl.eof() || !irsr.eof())
+      FATAL_ERROR("Pair of read files " + fnamel + " and " + fnamer + " contain unequal amount of reads");
+  return stats;
 }
 
 std::string getLargestPrefix(const std::string &str1, const std::string &str2) {
@@ -199,17 +201,26 @@ std::string getLargestPrefix(const std::string &str1, const std::string &str2) {
   return substr;
 }
 
+std::string CorrectSingleReadSet(size_t ilib, size_t iread, const std::string &fn, CorrectionStats &stats) {
+  std::string usuffix = std::to_string(ilib) + "_" +
+                        std::to_string(iread) + ".cor.fastq";
+
+  std::string outcor = getReadsFilename(cfg::get().output_dir, fn, Globals::iteration_no, usuffix);
+  std::ofstream ofgood(outcor.c_str());
+  std::ofstream ofbad(getReadsFilename(cfg::get().output_dir, fn, Globals::iteration_no, "bad.fastq").c_str(),
+                      std::ios::out | std::ios::ate);
+  stats += CorrectReadFile(*Globals::kmer_data, fn, &ofgood, &ofbad);
+  return outcor;
+}
+
 size_t CorrectAllReads() {
   // Now for the reconstruction step; we still have the reads in rv, correcting them in place.
-  size_t changedReads = 0;
-  size_t changedNucleotides = 0;
-  size_t uncorrectedNucleotides = 0;
-  size_t totalNucleotides = 0;
-
   int correct_nthreads = std::min(cfg::get().correct_nthreads, cfg::get().general_max_nthreads);
 
   INFO("Starting read correction in " << correct_nthreads << " threads.");
 
+  CorrectionStats stats;
+
   const io::DataSet<> &dataset = cfg::get().dataset;
   io::DataSet<> outdataset;
   size_t ilib = 0;
@@ -237,39 +248,32 @@ size_t CorrectAllReads() {
                            std::ios::out | std::ios::ate);
       std::ofstream ofunp (outcoru.c_str());
 
-      CorrectPairedReadFiles(*Globals::kmer_data,
-                             changedReads, changedNucleotides, uncorrectedNucleotides, totalNucleotides,
+      stats += CorrectPairedReadFiles(*Globals::kmer_data,
                              I->first, I->second,
                              &ofbadl, &ofcorl, &ofbadr, &ofcorr, &ofunp);
       outlib.push_back_paired(outcorl, outcorr);
       outlib.push_back_single(outcoru);
     }
 
+    for (auto I = lib.merged_begin(), E = lib.merged_end(); I != E; ++I, ++iread) {
+      INFO("Correcting merged reads: " << *I);
+      outlib.push_back_merged(CorrectSingleReadSet(ilib, iread, *I, stats));
+    }
+
     for (auto I = lib.single_begin(), E = lib.single_end(); I != E; ++I, ++iread) {
       INFO("Correcting single reads: " << *I);
-      std::string usuffix =  std::to_string(ilib) + "_" +
-                             std::to_string(iread) + ".cor.fastq";
-
-      std::string outcor = getReadsFilename(cfg::get().output_dir, *I,  Globals::iteration_no, usuffix);
-      std::ofstream ofgood(outcor.c_str());
-      std::ofstream ofbad(getReadsFilename(cfg::get().output_dir, *I,  Globals::iteration_no, "bad.fastq").c_str(),
-                          std::ios::out | std::ios::ate);
-
-      CorrectReadFile(*Globals::kmer_data,
-                      changedReads, changedNucleotides, uncorrectedNucleotides, totalNucleotides,
-                      *I,
-                      &ofgood, &ofbad);
-      outlib.push_back_single(outcor);
+      outlib.push_back_single(CorrectSingleReadSet(ilib, iread, *I, stats));
     }
+
     outdataset.push_back(outlib);
     ilib += 1;
   }
 
   cfg::get_writable().dataset = outdataset;
 
-  INFO("Correction done. Changed " << changedNucleotides << " bases in " << changedReads << " reads.");
-  INFO("Failed to correct " << uncorrectedNucleotides << " bases out of " << totalNucleotides << ".");
-  return changedReads;
+  INFO("Correction done. Changed " << stats.changedNucleotides << " bases in " << stats.changedReads << " reads.");
+  INFO("Failed to correct " << stats.uncorrectedNucleotides << " bases out of " << stats.totalNucleotides << ".");
+  return stats.changedReads;
 }
 
 };
