@@ -9,11 +9,9 @@
 #include "io/dataset_support/read_converter.hpp"
 
 #include "pair_info_count.hpp"
-#include "modules/alignment/short_read_mapper.hpp"
 #include "modules/alignment/long_read_mapper.hpp"
 #include "modules/alignment/bwa_sequence_mapper.hpp"
 #include "paired_info/pair_info_filler.hpp"
-#include "modules/path_extend/split_graph_pair_info.hpp"
 #include "modules/alignment/rna/ss_coverage_filler.hpp"
 
 
@@ -22,9 +20,25 @@
 
 namespace debruijn_graph {
 
-typedef io::SequencingLibrary<config::DataSetData> SequencingLib;
+typedef io::SequencingLibrary<config::LibraryData> SequencingLib;
 using PairedInfoFilter = bf::counting_bloom_filter<std::pair<EdgeId, EdgeId>, 2>;
-using EdgePairCounter = hll::hll<std::pair<EdgeId, EdgeId>>;
+using EdgePairCounter = hll::hll_with_hasher<std::pair<EdgeId, EdgeId>>;
+
+std::shared_ptr<SequenceMapper<Graph>> ChooseProperMapper(const conj_graph_pack& gp,
+                                                          const SequencingLib& library) {
+    if (library.type() == io::LibraryType::MatePairs) {
+        INFO("Mapping mate-pairs using BWA-mem mapper");
+        return std::make_shared<alignment::BWAReadMapper<Graph>>(gp.g);
+    }
+
+    if (library.data().unmerged_read_length < gp.k_value && library.type() == io::LibraryType::PairedEnd) {
+        INFO("Mapping PE reads shorter than K with BWA-mem mapper");
+        return std::make_shared<alignment::BWAReadMapper<Graph>>(gp.g);
+    }
+
+    INFO("Selecting usual mapper");
+    return MapperInstance(gp);
+}
 
 class DEFilter : public SequenceMapperListener {
   public:
@@ -183,11 +197,12 @@ static bool CollectLibInformation(const conj_graph_pack &gp,
 
     SequencingLib &reads = cfg::get_writable().ds.reads[ilib];
     auto &data = reads.data();
-    auto paired_streams = paired_binary_readers(reads, false);
+    auto paired_streams = paired_binary_readers(reads, /*followed by rc*/false, /*insert_size*/0,
+                                                /*include_merged*/true);
 
-    notifier.ProcessLibrary(paired_streams, ilib, *ChooseProperMapper(gp, reads, cfg::get().bwa.bwa_enable));
+    notifier.ProcessLibrary(paired_streams, ilib, *ChooseProperMapper(gp, reads));
     //Check read length after lib processing since mate pairs a not used until this step
-    VERIFY(reads.data().read_length != 0);
+    VERIFY(reads.data().unmerged_read_length != 0);
 
     auto pres = pcounter.cardinality();
     edgepairs = (!pres.second ? 64ull * 1024 * 1024 : size_t(pres.first));
@@ -242,7 +257,7 @@ static void ProcessSingleReads(conj_graph_pack &gp,
         notifier.Subscribe(ilib, &ss_coverage_filler);
     }
 
-    auto mapper_ptr = ChooseProperMapper(gp, reads, cfg::get().bwa.bwa_enable);
+    auto mapper_ptr = ChooseProperMapper(gp, reads);
     if (use_binary) {
         auto single_streams = single_binary_readers(reads, false, map_paired);
         notifier.ProcessLibrary(single_streams, ilib, *mapper_ptr);
@@ -255,13 +270,12 @@ static void ProcessSingleReads(conj_graph_pack &gp,
 
 
 static void ProcessPairedReads(conj_graph_pack &gp,
-                               std::unique_ptr<PairedInfoFilter> filter, unsigned filter_threshold,
+                               std::unique_ptr<PairedInfoFilter> filter,
+                               unsigned filter_threshold,
                                size_t ilib) {
     SequencingLib &reads = cfg::get_writable().ds.reads[ilib];
     const auto &data = reads.data();
 
-    bool calculate_threshold = (reads.type() == io::LibraryType::PairedEnd &&
-        !cfg::get().pe_params.param_set.extension_options.use_default_single_threshold);
     unsigned round_thr = 0;
     // Do not round if filtering is disabled
     if (filter)
@@ -274,17 +288,6 @@ static void ProcessPairedReads(conj_graph_pack &gp,
          ", filtering threshold " << filter_threshold <<
          ", rounding threshold " << round_thr);
 
-    path_extend::SplitGraphPairInfo
-            split_graph(gp, (size_t)data.median_insert_size,
-                        (size_t) data.insert_size_deviation,
-                        (size_t) data.insert_size_left_quantile,
-                        (size_t) data.insert_size_right_quantile,
-                        data.read_length, gp.g.k(),
-                        cfg::get().pe_params.param_set.split_edge_length,
-                        data.insert_size_distribution);
-    if (calculate_threshold)
-        notifier.Subscribe(ilib, &split_graph);
-
     LatePairedIndexFiller::WeightF weight;
     if (filter) {
         weight = [&](const std::pair<EdgeId, EdgeId> &ep,
@@ -303,9 +306,9 @@ static void ProcessPairedReads(conj_graph_pack &gp,
                               gp.paired_indices[ilib]);
     notifier.Subscribe(ilib, &pif);
 
-    auto paired_streams = paired_binary_readers(reads, false, (size_t) data.mean_insert_size);
-    notifier.ProcessLibrary(paired_streams, ilib, *ChooseProperMapper(gp, reads, cfg::get().bwa.bwa_enable));
-    cfg::get_writable().ds.reads[ilib].data().pi_threshold = split_graph.GetThreshold();
+    auto paired_streams = paired_binary_readers(reads, /*followed by rc*/false, (size_t) data.mean_insert_size,
+                                                /*include merged*/true);
+    notifier.ProcessLibrary(paired_streams, ilib, *ChooseProperMapper(gp, reads));
 }
 
 void PairInfoCount::run(conj_graph_pack &gp, const char *) {
@@ -327,7 +330,7 @@ void PairInfoCount::run(conj_graph_pack &gp, const char *) {
             if (lib.is_paired()) {
                 INFO("Estimating insert size for library #" << i);
                 const auto &lib_data = lib.data();
-                size_t rl = lib_data.read_length;
+                size_t rl = lib_data.unmerged_read_length;
                 size_t k = cfg::get().K;
 
                 size_t edgepairs = 0;
@@ -348,7 +351,7 @@ void PairInfoCount::run(conj_graph_pack &gp, const char *) {
                      ", deviation = " << lib_data.insert_size_deviation <<
                      ", left quantile = " << lib_data.insert_size_left_quantile <<
                      ", right quantile = " << lib_data.insert_size_right_quantile <<
-                     ", read length = " << lib_data.read_length);
+                     ", read length = " << lib_data.unmerged_read_length);
 
                 if (lib_data.mean_insert_size < 1.1 * (double) rl)
                     WARN("Estimated mean insert size " << lib_data.mean_insert_size
@@ -371,9 +374,9 @@ void PairInfoCount::run(conj_graph_pack &gp, const char *) {
                         DEFilter filter_counter(*filter, gp.g);
                         notifier.Subscribe(i, &filter_counter);
 
-                        auto reads = paired_binary_readers(lib, false);
-                        VERIFY(lib.data().read_length != 0);
-                        notifier.ProcessLibrary(reads, i, *ChooseProperMapper(gp, lib, cfg::get().bwa.bwa_enable));
+                        VERIFY(lib.data().unmerged_read_length != 0);
+                        auto reads = paired_binary_readers(lib, /*followed by rc*/false, 0, /*include merged*/true);
+                        notifier.ProcessLibrary(reads, i, *ChooseProperMapper(gp, lib));
                     }
                 }
 
@@ -392,8 +395,6 @@ void PairInfoCount::run(conj_graph_pack &gp, const char *) {
             }
         }
     }
-
-    SensitiveReadMapper<Graph>::EraseIndices();
 }
 
 }
