@@ -43,13 +43,15 @@ filtering_types = ["hard", "soft", "default"]
 #other constants
 MIN_K = 1
 MAX_K = 127
+RNA_MIN_K = 29
+RNA_MAX_LOWER_K = 55
 THRESHOLD_FOR_BREAKING_SCAFFOLDS = 3
 THRESHOLD_FOR_BREAKING_ADDITIONAL_CONTIGS = 10
 
 #default values constants
 THREADS = 16
 MEMORY = 250
-K_MERS_RNA = [55]
+K_MERS_RNA = [33,49]
 K_MERS_SHORT = [21,33,55]
 K_MERS_150 = [21,33,55,77]
 K_MERS_250 = [21,33,55,77,99,127]
@@ -74,7 +76,6 @@ only_assembler = False
 disable_gzip_output = None
 disable_rr = None
 careful = None
-diploid_mode = False
 
 # advanced options
 continue_mode = False
@@ -130,7 +131,7 @@ correct_scaffolds = False
 run_truseq_postprocessing = False
 
 #rna options
-strand_specific = None  # None, True, False are possible
+strand_specificity = None  # None, 'rf', 'fr' are possible
 fast = None
 
 dict_of_prefixes = dict()
@@ -144,7 +145,7 @@ long_options = "12= merged= threads= memory= tmp-dir= iterations= phred-offset=
                "help version test debug debug:false reference= series-analysis= config-file= dataset= "\
                "bh-heap-check= spades-heap-check= read-buffer-size= help-hidden "\
                "mismatch-correction mismatch-correction:false careful careful:false save-gp save-gp:false "\
-               "continue restart-from= diploid truseq cov-cutoff= hidden-cov-cutoff= read-cov-threshold= " \
+               "continue restart-from= truseq cov-cutoff= hidden-cov-cutoff= read-cov-threshold= " \
                "configs-dir= stop-after=".split()
 short_options = "o:1:2:s:k:t:m:i:hv"
 
@@ -211,10 +212,8 @@ def usage(spades_version, show_hidden=False, mode=None):
     sys.stderr.write("-v/--version\t\tprints version" + "\n")
 
     sys.stderr.write("" + "\n")
-    if mode != "dip":
-        sys.stderr.write("Input data:" + "\n")
-    else:
-        sys.stderr.write("Input reads:" + "\n")
+    sys.stderr.write("Input data:" + "\n")
+
     sys.stderr.write("--12\t<filename>\tfile with interlaced forward and reverse"\
                          " paired-end reads" + "\n")
     sys.stderr.write("-1\t<filename>\tfile with forward paired-end reads" + "\n")
@@ -272,39 +271,30 @@ def usage(spades_version, show_hidden=False, mode=None):
     if not mode == "meta":
         sys.stderr.write("--trusted-contigs\t<filename>\tfile with trusted contigs\n")
         sys.stderr.write("--untrusted-contigs\t<filename>\tfile with untrusted contigs\n")
-    if mode == "dip":
-        sys.stderr.write("Input haplocontigs:" + "\n")
-        sys.stderr.write("--hap\t<filename>\tfile with haplocontigs" + "\n")
+
     if mode == "rna":
         sys.stderr.write("--ss-<type>\tstrand specific data, <type> = fr (normal) and rf (antisense)\n")
 
     sys.stderr.write("" + "\n")
     sys.stderr.write("Pipeline options:" + "\n")
-    if mode != "dip":
-        sys.stderr.write("--only-error-correction\truns only read error correction"\
-                             " (without assembling)" + "\n")
+
+    sys.stderr.write("--only-error-correction\truns only read error correction"\
+                         " (without assembling)" + "\n")
     sys.stderr.write("--only-assembler\truns only assembling (without read error"\
                          " correction)" + "\n")
-    if mode != "dip":
-        if mode not in ["rna", "meta"]:
-            sys.stderr.write("--careful\t\ttries to reduce number of mismatches and short indels" + "\n")
-        sys.stderr.write("--continue\t\tcontinue run from the last available check-point" + "\n")
-        if mode == "rna":
-            sys.stderr.write("--restart-from\t<cp>\trestart run with updated options and from the specified check-point ('ec', 'as', 'last')" + "\n")
-        else:
-            sys.stderr.write("--restart-from\t<cp>\trestart run with updated options and from the specified check-point ('ec', 'as', 'k<int>', 'mc', 'last')" + "\n")
+
+    if mode not in ["rna", "meta"]:
+        sys.stderr.write("--careful\t\ttries to reduce number of mismatches and short indels" + "\n")
+    sys.stderr.write("--continue\t\tcontinue run from the last available check-point" + "\n")
+    if mode == "rna":
+        sys.stderr.write("--restart-from\t<cp>\trestart run with updated options and from the specified check-point ('ec', 'as', 'last')" + "\n")
+    else:
+        sys.stderr.write("--restart-from\t<cp>\trestart run with updated options and from the specified check-point ('ec', 'as', 'k<int>', 'mc', 'last')" + "\n")
     sys.stderr.write("--disable-gzip-output\tforces error correction not to"\
                          " compress the corrected reads" + "\n")
     sys.stderr.write("--disable-rr\t\tdisables repeat resolution stage"\
                      " of assembling" + "\n")
 
-    if mode == "dip":
-        sys.stderr.write("" + "\n")
-        sys.stderr.write("DipSPAdes options:" + "\n")
-        sys.stderr.write("--expect-gaps\t\tindicates that significant number of gaps in coverage is expected" + "\n")
-        sys.stderr.write("--expect-rearrangements\tindicates that significant number of rearrangements between haplomes of diploid genome is expected" + "\n")
-        sys.stderr.write("--hap-assembly\t\tenables haplotype assembly phase" + "\n")
-
     sys.stderr.write("" + "\n")
     sys.stderr.write("Advanced options:" + "\n")
     sys.stderr.write("--dataset\t<filename>\tfile with dataset description in YAML format" + "\n")
@@ -358,15 +348,6 @@ def usage(spades_version, show_hidden=False, mode=None):
         sys.stderr.write("--read-cov-threshold\t<int>\t\tread median coverage threshold (non-negative integer)\n")
         sys.stderr.write("--help-hidden\tprints this usage message with all hidden options" + "\n")
 
-    if show_hidden and mode == "dip":
-        sys.stderr.write("" + "\n")
-        sys.stderr.write("HIDDEN dipSPAdes options:" + "\n")
-        sys.stderr.write("--dsK\t\t<int>\t\tk value used in dipSPAdes [default: '55']" + '\n')
-        sys.stderr.write("--dsdebug\t\t\tmakes saves and draws pictures" + '\n')
-        sys.stderr.write("--saves\t<directory>\tdirectory with saves which will be used for graph loading" + '\n')
-        sys.stderr.write("--start-from\t<start_point>\tstart point of dipSPAdes:" + '\n')
-        sys.stderr.write("    pbr: polymorphic bulge remover\n    kmg: gluer of equal k-mers\n    cc: consensus constructor\n    ha: haplotype assembly" + '\n')
-
     sys.stderr.flush()
 
 
@@ -443,7 +424,7 @@ def save_restart_options(log):
         support.error("you cannot specify --only-assembler with --restart-from option!", log)
     if only_error_correction:
         support.error("you cannot specify --only-error-correction with --restart-from option!", log)
-    if strand_specific is not None:
+    if strand_specificity is not None:
         support.error("you cannot specify strand specificity (--ss-rf or --ss-fr) with --restart-from option!", log)
 
     global restart_k_mers
