@@ -72,8 +72,8 @@ def prepare_config_rnaspades(filename, log):
     if not options_storage.rna:
         return
     subst_dict = dict()
-    subst_dict["ss_enabled"] = bool_to_str(options_storage.strand_specific is not None)
-    subst_dict["antisense"] = bool_to_str(options_storage.strand_specific)
+    subst_dict["ss_enabled"] = bool_to_str(options_storage.strand_specificity is not None)
+    subst_dict["antisense"] = bool_to_str(options_storage.strand_specificity == 'rf')
     process_cfg.substitute_params(filename, subst_dict, log)
 
 
@@ -142,9 +142,8 @@ def add_configs(command, configs_dir):
                            ("truseq_mode", "moleculo_mode"),
                            ("rna", "rna_mode"),
                            ("large_genome", "large_genome_mode"),
-                           ("plasmid", "plasmid_mode"),
+                           ("plasmid", "plasmid_mode")]
                            #("careful", "careful_mode"),
-                           ("diploid_mode", "diploid_mode")]
     for (mode, config) in mode_config_mapping:
         if options_storage.__dict__[mode]:
             if mode == "rna" or mode == "meta":
